@@ -1846,7 +1846,7 @@ class Update(MethodsInterface):
         self.clVars.Set('update.cl_update_binhost_data',
             retval or Variable.EmptyTable, force=True)
         if not ignore_level:
-            best_binhost_level = int(self.clVars.Get("update.cl_update_binhost_level")[0])
+            best_binhost_level = int(self.clVars.Get("update.cl_update_binhost_level")[0]) or None
             #int(sorted(self.clVars.Get("update.cl_update_binhost_level"), key=int)[-1])
             # int(self.clVars.Get("update.cl_update_binhost_level")[0])
             
