@@ -25,3 +25,5 @@ class EmergeMark:
     PreservedLibs = "update preserved libs"
     RevdepRebuild = "revdep rebuild"
     Prelink = "prelink"
+    Automagic = "check for auto depends"
+    SaveTag = "save latest calculate update tag"
