@@ -84,7 +84,8 @@ def get_synchronization_tasks(object_name):
                   'depend': (Tasks.success() & ~AllTasks.has_any("not_use_search") &
                              (~AllTasks.success_one_of("check_current_binhost") |
                              AllTasks.success_all("sync_reps"))),
-                  'condition': lambda Get: Get('update.cl_update_use_migration_host') == 'off'
+                  'condition': lambda Get: Get('update.cl_update_use_migration_host') == 'off' and
+                                           not Get("update.cl_update_binhost_choice")
                  },
                  {'name': 'interrupt_on_no_leveled_binhost',
                   'method': Object("interrupt_on_no_leveled_binhost()"),
