@@ -51,7 +51,7 @@ class ClUpdateProfileAction(Action):
          'condition': lambda Get: not (
              Get('cl_update_profile_storage').is_local(
                  Get('cl_update_profile_url'),
-                 Get('cl_update_profile_branch'))) or Get('cl_update_profile_check_sync_allowed')
+                 Get('cl_update_profile_branch'))) and Get('cl_update_profile_check_sync_allowed')
          },
         {'name': 'reconfigure_vars1',
          'method': 'Update.invalidateVariables("cl_update_profile_storage")',
@@ -73,7 +73,7 @@ class ClUpdateProfileAction(Action):
          'tasks': [
              {'name': 'sync_reps',
               'foreach': 'cl_update_profile_sync_rep',
-              'message': __("Syncing the {eachvar:capitalize} repository"),
+              'message': __("Checking {eachvar:capitalize} updates"),
               'method': 'Update.syncRepositories(eachvar)',
               'condition': lambda Get: Get('cl_update_profile_check_sync_allowed')
               },
