@@ -640,6 +640,11 @@ class VariableClUpdateOtherSet(Variable):
     """
     type = "bool"
     value = "on"
+    metavalue = _("Other overlays")
+
+    def init(self):
+        self.label = _("Update other overlays")
+        self.help = _("Update other overlays")
 
     def get(self):
         if self.Get('cl_update_inner_other_set') != 'auto':
